# $Id: finance.rb,v 1.6 2004/07/12 01:15:02 ianmacd Exp $

require 'uri'

#:include: ../README.rdoc
#
module Finance


  # Returns an array of [ _host_, _port_, _user_, _password_ ], based on the
  # setting of <b>$http_proxy</b>. Each of these will be *nil* if the
  # corresponding data element is not set.
  #
  # This method is likely to be of little use to you, as it is primarily
  # intended for the internal use of Ruby/Finance.
  #
  def Finance.proxy_data
    begin
      uri = URI.parse( ENV['http_proxy'] )
      proxy_host = uri.host
      proxy_port = uri.port
      proxy_user, proxy_pass = uri.userinfo.split( /:/ ) if uri.userinfo
    rescue URI::InvalidURIError
    end

    return [ proxy_host, proxy_port, proxy_user, proxy_pass ]
  end


  class Quote
  
    # This is used to register a plug-in module with Ruby/Finance. As such,
    # this method is generally only useful if you are extending Ruby/Finance
    # itself.
    #
    # _mod_ should be the name of the module to register, with _methods_ being
    # a Hash of exchange-to-method mappings.
    #
    # For example:
    #
    #  register_plugin( Finance::Quote::Yahoo::Australia,
    #                   { :australia => :yahoo_australia,
    #                     :yahoo_australia => :yahoo_australia } )
    #
    def Quote.register_plugin( mod, methods )
      @@plugins ||= []
      @@plugins << mod

      @@delegates ||= {}
      @@delegates.merge!( methods )
    end

    # Returns a list of registered plug-in modules.
    #
    def Quote.plugins
      @@plugins
    end

  end

end
