# $Id: currency.rb,v 1.3 2004/07/08 08:38:05 ianmacd Exp $
#

require 'uri'
require 'net/http'
require 'finance'

module Finance


  # This module handles currency operations.
  #
  module Currency


    # This exception is raised when a currency's exchange rate cannot be
    # determined. This usually means a non-existent currency was used.
    #
    class RateError < StandardError; end

    attr_accessor :currency


    # Where to obtain currency information.
    # 
    CURRENCY_URL = 'http://uk.finance.yahoo.com/m5'

    DEFAULT_CURRENCY_FIELDS =
      %w[ last high low net bid ask close open day_range year_range
	  eps div cap nav price ].map { |field| field.to_sym }


    # Convert one currency to another. The following example converts US $100
    # into Euros:
    #
    #  Finance::Currency::convert( 'EUR', 'USD', 100 )
    #
    def Currency.convert( to, from, amount=1 )

      # Allow amount to be passed as a string.
      amount = amount.to_f if amount.kind_of?( String )

      # We always want to convert at least 1 of something.
      amount = 1 if amount == 0 || amount.nil?

      # Return immediately if there's no work to do.
      return amount.to_f if from == to

      yahoo = URI.parse( CURRENCY_URL )
      host = yahoo.host
      path = yahoo.path

      ## Transparently deal with an HTTP proxy server.
      Net::HTTP::Proxy( *Finance::proxy_data ).start( host, 80 ) do |http|
	response = http.get( path + "?s=%s&t=%s" % [ from, to ] )
	body = response.body
	body =~ %r{#{from}#{to}=X</a></th><th>1</th><th(?: nowrap)?>[^<]+</th><t[dh]>(\d+\.\d+)</t[dh]>}

	exchange_rate = $1.to_f	  # Must be a Float for conversion to work

	if exchange_rate == 0
	  raise RateError, "Exchange rate could not be determined."
	end

	exchange_rate * amount
      end
    end

  end

end
