# $Id: asia.rb,v 1.5 2004/07/09 09:03:18 ianmacd Exp $
#

module Finance
  class Quote
    module Yahoo

      # = Fetch quotes from Yahoo Asia.
      #
      #  q = Quote.new
      #  qd = q.fetch( 'asia', 'CREA.SI' )
      #  qd = q.fetch( 'yahoo_asia', 'CREA.SI' )  # alternative form
      #
      # This module fetches information from Yahoo Asia. Symbols should be
      # provided in the format <b>SYMBOL.EXCHANGE</b>, where the exchange code
      # is one of the following:
      #
      #  SI - Singapore
      #  BO - Bombay
      #  JK - Jakarta
      #  HK - Hong Kong
      #  NS - India
      #  KS - Korea
      #  KL - Kuala Lumpur
      #  NZ - New Zealand
      #  SS - Shanghai
      #  SZ - Shenzhen
      #  TW - Taiwan
      #  TH - Thailand
      #
      # Stocks are returned in the currency of the local exchange. You can set
      # the <em>@currency</em> attribute of your Finance::Quote object to
      # change the currency in which information is returned.
      #
      # Information obtained by this module may be covered by Yahoo's terms
      # and conditions. See http://sg.finance.yahoo.com/ for more details.
      #
      module Asia

	Finance::Quote::register_plugin( self, { :asia => :yahoo_asia,
						 :yahoo_asia => :yahoo_asia } )

	# URL from where to obtain information.
	YAHOO_ASIA_URL = 'http://sg.finance.yahoo.com/d/quotes.csv'

	def yahoo_asia( *symbols )
	  symbols.flatten!
	  info =
	    Finance::Quote::Yahoo::yahoo_request( YAHOO_ASIA_URL, symbols )

	  symbols.each do |symbol|
	    next unless info[symbol][:success]

	    info[symbol][:method] = :yahoo_asia
	  end

	  return info
	end

      end
    end
  end
end
