# $Id: australia.rb,v 1.4 2004/07/09 09:40:42 ianmacd Exp $
#

module Finance
  class Quote
    module Yahoo

      # = Fetch quotes from Yahoo Australia.
      #
      #  q = Quote.new
      #  qd = q.fetch( 'australia', 'BHP' )
      #  qd = q.fetch( 'yahoo_australia', 'BHP' )  # alternative form
      #
      # This module allows the fetching of information about stocks traded on
      # the Australian Stock Exchange. Information about indexes (such as the
      # All Ordinaries) is not available through this module.
      #
      # Stocks are returned in Australian dollars. You can set the
      # <em>@currency</em> attribute of your Finance::Quote object to change
      # the currency in which information is returned.
      #
      # Information obtained via this module is governed by Yahoo's terms and
      # conditions, see http://au.finance.yahoo.com/ for more details.
      # 
      module Australia

	Finance::Quote::
	  register_plugin( self,
			   { :australia => :yahoo_australia,
			     :yahoo_australia => :yahoo_australia } )

	# URL from where to obtain information.
	YAHOO_AUSTRALIA_URL = 'http://au.finance.yahoo.com/d/quotes.csv'

	def yahoo_australia( *symbols )
	  symbols.flatten!
	  info = Finance::Quote::Yahoo::yahoo_request( YAHOO_AUSTRALIA_URL,
						       symbols,
						       '.AX' )

	  symbols.each do |symbol|
	    next unless info[symbol][:success]

	    info[symbol][:exchange] = 'Australian Stock Exchange'
	    info[symbol][:method] = :yahoo_australia
	  end

	  return info
	end

      end
    end
  end
end
